@@ -554,6 +554,9 @@ public class BasicInformationView extends Composite implements FormValidator {
 	 */
 	public List<ZenodoCreator> getListOfCreators() {
 		List<ZenodoCreator> listOfCreators = new ArrayList<>();
+		if(listOfCreatorsView==null) {
+			return listOfCreators;
+		}
 		for (CreatorsFormView cfv : listOfCreatorsView) {
 			List<? extends ZenodoAuthor> listOfUsers = cfv.readListOfCreatorsFromView();
 			for (ZenodoAuthor zenodoAuthor : listOfUsers) {
@@ -570,11 +573,15 @@ public class BasicInformationView extends Composite implements FormValidator {
 	 */
 	public List<ZenodoContributor> getListOfContributors() {
 		List<ZenodoContributor> listOfContributors = new ArrayList<>();
+		if(listOfContributorsView==null) {
+			return listOfContributors;
+		}
 		for (CreatorsFormView cfv : listOfContributorsView) {
 			List<? extends ZenodoAuthor> listOfUsers = cfv.readListOfCreatorsFromView();
 			for (ZenodoAuthor zenodoAuthor : listOfUsers) {
 				listOfContributors.add((ZenodoContributor) zenodoAuthor);
 			}
+		
 		}
 		return listOfContributors;
 	}
